<?php

namespace Photo\Photo\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Photo\Photo\Http\Requests\OrderItemAdminRequest;
use Photo\Photo\Interfaces\OrderItemRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class OrderItemAdminController extends AdminController
{
    /**
     * Initialize order_item controller.
     *
     * @param type OrderItemRepositoryInterface $order_item
     *
     * @return type
     */
    public function __construct(OrderItemRepositoryInterface $order_item)
    {
        $this->model = $order_item;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(OrderItemAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('photo.order_item.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('photo::order_item.names').' :: ');

        return $this->theme->of('photo::admin.order_item.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(OrderItemAdminRequest $request, $id)
    {
        $order_item = $this->model->find($id);

        if (empty($order_item)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('photo::admin.order_item.new');
        }

        if ($request->wantsJson()) {
            return $order_item;
        }

        Former::populate($order_item);

        return view('photo::admin.order_item.show', compact('order_item'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(OrderItemAdminRequest $request)
    {
        $order_item = $this->model->findOrNew(0);
        Former::populate($order_item);

        return view('photo::admin.order_item.create', compact('order_item'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OrderItemAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $order_item = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('photo::order_item.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(OrderItemAdminRequest $request, $id)
    {
        $order_item = $this->model->find($id);

        Former::populate($order_item);

        return view('photo::admin.order_item.edit', compact('order_item'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(OrderItemAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $order_item = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('photo::order_item.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(OrderItemAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('photo::order_item.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
