<?php

namespace Photo\Photo\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Photo\Photo\Http\Requests\OrderItemUserRequest;
use Photo\Photo\Interfaces\OrderItemRepositoryInterface;
use Response;
use User;

class OrderItemUserController extends UserController
{
    /**
     * Initialize order_item controller.
     *
     * @param type OrderItemRepositoryInterface $order_item
     *
     * @return type
     */
    public function __construct(OrderItemRepositoryInterface $order_item)
    {
        $this->model = $order_item;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(OrderItemUserRequest $request)
    {
        $order_items = $this->model->all();

        $this->theme->prependTitle(trans('photo::order_item.names').' :: ');

        return $this->theme->of('photo::user.order_item.index', compact('order_items'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(OrderItemUserRequest $request, $role, $id)
    {
        $order_item = $this->model->find($id);

        return $this->theme->of('photo::user.order_item.show', compact('order_item'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(OrderItemUserRequest $request)
    {
        $order_item = $this->model->findOrNew(0);

        Former::populate($order_item);

        return $this->theme->of('photo::user.order_item.create', compact('order_item'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OrderItemUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $order_item = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('photo::order_item.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(OrderItemUserRequest $request, $role, $id)
    {
        $order_item = $this->model->find($id);

        Former::populate($order_item);

        return $this->theme->of('photo::user.order_item.edit', compact('order_item'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(OrderItemUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $order_item = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('photo::order_item.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(OrderItemUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('photo::order_item.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
