<?php

namespace Photo\Photo\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Photo\Photo\Http\Requests\OrdersAdminRequest;
use Photo\Photo\Interfaces\OrdersRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class OrdersAdminController extends AdminController
{
    /**
     * Initialize orders controller.
     *
     * @param type OrdersRepositoryInterface $orders
     *
     * @return type
     */
    public function __construct(OrdersRepositoryInterface $orders)
    {
        $this->model = $orders;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(OrdersAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('photo.orders.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('photo::orders.names').' :: ');

        return $this->theme->of('photo::admin.orders.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(OrdersAdminRequest $request, $id)
    {
        $orders = $this->model->find($id);

        if (empty($orders)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('photo::admin.orders.new');
        }

        if ($request->wantsJson()) {
            return $orders;
        }

        Former::populate($orders);

        return view('photo::admin.orders.show', compact('orders'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(OrdersAdminRequest $request)
    {
        $orders = $this->model->findOrNew(0);
        Former::populate($orders);

        return view('photo::admin.orders.create', compact('orders'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OrdersAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $orders = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('photo::orders.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(OrdersAdminRequest $request, $id)
    {
        $orders = $this->model->find($id);

        Former::populate($orders);

        return view('photo::admin.orders.edit', compact('orders'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(OrdersAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $orders = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('photo::orders.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(OrdersAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('photo::orders.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
