<?php

namespace Photo\Photo\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Photo\Photo\Http\Requests\OrdersUserRequest;
use Photo\Photo\Interfaces\OrdersRepositoryInterface;
use Response;
use User;

class OrdersUserController extends UserController
{
    /**
     * Initialize orders controller.
     *
     * @param type OrdersRepositoryInterface $orders
     *
     * @return type
     */
    public function __construct(OrdersRepositoryInterface $orders)
    {
        $this->model = $orders;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(OrdersUserRequest $request)
    {
        $orders = $this->model->all();

        $this->theme->prependTitle(trans('photo::orders.names').' :: ');

        return $this->theme->of('photo::user.orders.index', compact('orders'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(OrdersUserRequest $request, $role, $id)
    {
        $orders = $this->model->find($id);

        return $this->theme->of('photo::user.orders.show', compact('orders'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(OrdersUserRequest $request)
    {
        $orders = $this->model->findOrNew(0);

        Former::populate($orders);

        return $this->theme->of('photo::user.orders.create', compact('orders'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OrdersUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $orders = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('photo::orders.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(OrdersUserRequest $request, $role, $id)
    {
        $orders = $this->model->find($id);

        Former::populate($orders);

        return $this->theme->of('photo::user.orders.edit', compact('orders'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(OrdersUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $orders = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('photo::orders.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(OrdersUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('photo::orders.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
