<?php

namespace Photo\Photo\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Photo\Photo\Http\Requests\ProductItemAdminRequest;
use Photo\Photo\Interfaces\ProductItemRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class ProductItemAdminController extends AdminController
{
    /**
     * Initialize product_item controller.
     *
     * @param type ProductItemRepositoryInterface $product_item
     *
     * @return type
     */
    public function __construct(ProductItemRepositoryInterface $product_item)
    {
        $this->model = $product_item;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ProductItemAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('photo.product_item.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('photo::product_item.names').' :: ');

        return $this->theme->of('photo::admin.product_item.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ProductItemAdminRequest $request, $id)
    {
        $product_item = $this->model->find($id);

        if (empty($product_item)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('photo::admin.product_item.new');
        }

        if ($request->wantsJson()) {
            return $product_item;
        }

        Former::populate($product_item);

        return view('photo::admin.product_item.show', compact('product_item'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ProductItemAdminRequest $request)
    {
        $product_item = $this->model->findOrNew(0);
        Former::populate($product_item);

        return view('photo::admin.product_item.create', compact('product_item'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ProductItemAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $product_item = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('photo::product_item.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ProductItemAdminRequest $request, $id)
    {
        $product_item = $this->model->find($id);

        Former::populate($product_item);

        return view('photo::admin.product_item.edit', compact('product_item'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ProductItemAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $product_item = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('photo::product_item.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ProductItemAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('photo::product_item.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
