<?php

namespace Photo\Photo\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Photo\Photo\Http\Requests\ProductItemUserRequest;
use Photo\Photo\Interfaces\ProductItemRepositoryInterface;
use Response;
use User;

class ProductItemUserController extends UserController
{
    /**
     * Initialize product_item controller.
     *
     * @param type ProductItemRepositoryInterface $product_item
     *
     * @return type
     */
    public function __construct(ProductItemRepositoryInterface $product_item)
    {
        $this->model = $product_item;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ProductItemUserRequest $request)
    {
        $product_items = $this->model->all();

        $this->theme->prependTitle(trans('photo::product_item.names').' :: ');

        return $this->theme->of('photo::user.product_item.index', compact('product_items'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ProductItemUserRequest $request, $role, $id)
    {
        $product_item = $this->model->find($id);

        return $this->theme->of('photo::user.product_item.show', compact('product_item'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ProductItemUserRequest $request)
    {
        $product_item = $this->model->findOrNew(0);

        Former::populate($product_item);

        return $this->theme->of('photo::user.product_item.create', compact('product_item'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ProductItemUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $product_item = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('photo::product_item.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ProductItemUserRequest $request, $role, $id)
    {
        $product_item = $this->model->find($id);

        Former::populate($product_item);

        return $this->theme->of('photo::user.product_item.edit', compact('product_item'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ProductItemUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $product_item = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('photo::product_item.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ProductItemUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('photo::product_item.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
