<?php

namespace Photo\Photo\Providers;

use Illuminate\Support\ServiceProvider;

class PhotoServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__.'/../../../../resources/views', 'photo');

        // Load translation
        $this->loadTranslationsFrom(__DIR__.'/../../../../resources/lang', 'photo');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__.'/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('photo', function ($app) {
            return $this->app->make('Photo\Photo\Photo');
        });

        // Repository binds
        // Bind Product to repository
        $this->app->bind(
            \Photo\Photo\Interfaces\ProductRepositoryInterface::class,
            \Photo\Photo\Repositories\Eloquent\ProductRepository::class
        );
        // Bind ProductItem to repository
        $this->app->bind(
            \Photo\Photo\Interfaces\ProductItemRepositoryInterface::class,
            \Photo\Photo\Repositories\Eloquent\ProductItemRepository::class
        );
        // Bind Orders to repository
        $this->app->bind(
            \Photo\Photo\Interfaces\OrdersRepositoryInterface::class,
            \Photo\Photo\Repositories\Eloquent\OrdersRepository::class
        );
        // Bind OrderItem to repository
        $this->app->bind(
            \Photo\Photo\Interfaces\OrderItemRepositoryInterface::class,
            \Photo\Photo\Repositories\Eloquent\OrderItemRepository::class
        );
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['photo'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__.'/../../../../config/config.php' => config_path('package/photo.php')], 'config');

        // Publish public view
        $this->publishes([__DIR__.'/../../../../resources/views/public'  => base_path('resources/views/vendor/photo/public')], 'view-public');

        // Publish admin view
        $this->publishes([__DIR__.'/../../../../resources/views/admin' => base_path('resources/views/vendor/photo/admin')], 'view-admin');

        // Publish language files
        $this->publishes([__DIR__.'/../../../../resources/lang' => base_path('resources/lang/vendor/courier')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__.'/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__.'/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
